@@ -111,7 +111,7 @@ qx.Class.define('callbackery.ui.plugin.Table', {
                             cfg.table.forEach(function(col,i){
                                 if (col.primary){
                                     gotPrimary = true;
-                                    if (currentData[col.key] != lastData[col.key]){
+                                    if (!qx.lang.Type.isObject(currentData) || !qx.lang.Type.isObject(lastData) || currentData[col.key] != lastData[col.key]){
                                         equal = false;
                                     }
                                 }
